@@ -118,7 +118,7 @@ static Interp_Type *alloc_interp_type (const gsl_interp_type *ic,
    if (NULL == (it = (Interp_Type *) SLmalloc (sizeof (Interp_Type))))
      return NULL;
 
-   memset ((char *) it, sizeof (Interp_Type), 0);
+   memset ((char *) it, 0, sizeof (Interp_Type));
 
    if (NULL == (it->g = gsl_interp_alloc (ic, na)))
      {
@@ -414,6 +414,7 @@ static void do_interp_integ (const gsl_interp_type *type)
 	slgsl_free_d_array (&ya);
 	slgsl_free_d_array (&a);
 	slgsl_free_d_array (&b);
+	return;
      }
 
    if (NULL == (it = alloc_interp_type (type, xa.at, ya.at)))
@@ -423,6 +424,7 @@ static void do_interp_integ (const gsl_interp_type *type)
 	slgsl_free_d_array (&ya);
 	slgsl_free_d_array (&a);
 	slgsl_free_d_array (&b);
+	return;
      }
    
    /* 'it' now owns xa, ya */
